@@ -223,10 +223,15 @@ std::string gdal_getconfig(std::string option) {
 
 // [[Rcpp::export(name = ".gdalinfo")]]
 std::string ginfo(std::string filename, std::vector<std::string> options, std::vector<std::string> oo) {
-	std::string out = gdalinfo(filename, options, oo);
-	return out;
+	return gdalinfo(filename, options, oo);
 }
 
+// [[Rcpp::export(name = ".gdalmdinfo")]]
+std::string gmdinfo(std::string filename, std::vector<std::string> options) {
+	return gdalMDinfo(filename, options);
+}
+
+
 // [[Rcpp::export(name = ".sdinfo")]]
 std::vector<std::vector<std::string>> sd_info(std::string filename) {
 	std::vector<std::vector<std::string>> sd = sdinfo(filename);
@@ -561,7 +566,7 @@ bool set_proj_search_paths(std::vector<std::string> paths) {
 	for (size_t i = 0; i < paths.size(); i++) {
 		cpaths[i] = (char *) (paths[i].c_str());
 	}
-	cpaths[cpaths.size()] = NULL;
+	cpaths[cpaths.size()-1] = NULL;
 	OSRSetPROJSearchPaths(cpaths.data());
 	return true;
 #else
@@ -587,6 +592,25 @@ std::string PROJ_network(bool enable, std::string url) {
 	return s;
 }
 
+
+
+// [[Rcpp::export(name = ".removeDriver")]]
+void removeDriver(std::vector<std::string> d) {
+	if ((d.size() == 0) || ((d.size() == 1) && (d[0] == ""))) {
+		GDALAllRegister();	
+	} else {
+		for (size_t i=0; i<d.size(); i++) {
+			GDALDriverH hDrv = GDALGetDriverByName(d[i].c_str());
+			if (hDrv == NULL) {
+				Rcpp::warning(d[i] + " is not a known driver\n");
+			} else {
+				GDALDeregisterDriver(hDrv);
+			}
+		}
+	}
+}
+
+
 // [[Rcpp::export(name = ".pearson")]]
 double pearson_cor(std::vector<double> x, std::vector<double> y, bool narm) {
  
@@ -716,3 +740,108 @@ double stattest2(std::vector<double> x, std::string fun, bool narm) {
 
 */
 
+
+Rcpp::List get_output(std::vector<std::string> names, std::vector<long> sizes) {
+	Rcpp::List L = Rcpp::List::create(Rcpp::Named("name") = names, Rcpp::Named("size") = sizes);
+	return(L);
+}
+
+
+#if GDAL_VERSION_MAJOR >= 3 && GDAL_VERSION_MINOR >= 4
+
+// [[Rcpp::export(name = ".arnames")]]
+std::vector<std::string> arnames(std::string filename, bool filter) {
+// FROM GDAL 3.11 (while not widely available).
+// * Author:   Even Rouault <even.rouault at spatialys.com>
+// * Copyright (c) 2019, Even Rouault <even.rouault at spatialys.com>
+
+    std::vector<std::string> ret;
+    auto poDataset = std::unique_ptr<GDALDataset>(GDALDataset::Open(filename.c_str(), GDAL_OF_MULTIDIM_RASTER ));
+
+    if (!poDataset) {
+		ret.push_back("not a good dataset");
+        return ret;
+    }
+
+	std::shared_ptr<GDALGroup> poRootGroup = poDataset->GetRootGroup();
+    if (!poRootGroup) {
+		ret.push_back("no root group");
+        return ret;
+    }
+
+    std::list<std::shared_ptr<GDALGroup>> stackGroups;
+    stackGroups.push_back(nullptr);  // nullptr means this
+    while (!stackGroups.empty()) {
+        std::shared_ptr<GDALGroup> groupPtr = std::move(stackGroups.front());
+        stackGroups.erase(stackGroups.begin());
+        const GDALGroup *poCurGroup = groupPtr ? groupPtr.get() : poRootGroup.get();
+        for (const std::string &arrayName :  poCurGroup->GetMDArrayNames(nullptr)) {
+            std::string osFullName = poCurGroup->GetFullName();
+            if (!osFullName.empty() && osFullName.back() != '/') 
+                osFullName += '/';
+            osFullName += arrayName;
+            ret.push_back(std::move(osFullName));
+        }
+        auto insertionPoint = stackGroups.begin();
+        for (const auto &osSubGroup : poCurGroup->GetGroupNames(nullptr)) {
+            auto poSubGroup = poCurGroup->OpenGroup(osSubGroup);
+            if (poSubGroup)
+                stackGroups.insert(insertionPoint, std::move(poSubGroup));
+        }
+    }
+	if (filter) {
+		ret = ncdf_filternames(ret);
+	}
+    return ret;
+}
+
+
+// [[Rcpp::export(name = ".dimfo")]]
+Rcpp::List dimfo(std::string filename, std::string array_name) {
+
+	std::vector<std::string> names;
+	std::vector<long> sizes;
+
+    auto poDataset = std::unique_ptr<GDALDataset>(GDALDataset::Open(filename.c_str(), GDAL_OF_MULTIDIM_RASTER ));
+    if (!poDataset) {
+		names.push_back("cannot open as md: " + filename);
+		sizes.push_back(-99);
+		return get_output(names, sizes);
+    }
+
+	std::shared_ptr<GDALGroup> poRootGroup = poDataset->GetRootGroup();
+    if (!poRootGroup) {
+		names.push_back("no root group: " + filename);
+		sizes.push_back(-99);
+		return get_output(names, sizes);
+    }
+
+	auto poVar = poRootGroup->OpenMDArray(array_name.c_str());
+	if (!poVar)   {
+		names.push_back("cannot open: " + array_name);
+		sizes.push_back(-99);
+		return get_output(names, sizes);
+	}
+
+	if (names.size() == 0) {
+		for ( const auto &poDim: poVar->GetDimensions() ) {
+			names.push_back(static_cast<std::string>(poDim->GetName()));
+			sizes.push_back(static_cast<long>(poDim->GetSize()));
+		}
+	}
+	return get_output(names, sizes);
+}
+
+#else
+
+Rcpp::List dimfo(std::string filename, std::string array_name) {
+	return get_output({"not supported with GDAL < 3.4"}, {-99});
+}
+
+std::vector<std::string> arnames(std::string filename, bool filter) {
+	std::vector<std::string> out(1, "not supported with GDAL < 3.4");
+	return out;
+}
+
+#endif
+
